@@ -17,15 +17,6 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "{user} قام بأرشفة اللوح {before}",
     "You have unarchived the board {board}" : "قمت بالغاء ارشفة اللوح {board}",
     "{user} has unarchived the board {before}" : "{user} قام بالغاء ارشفة اللوح {before}",
-    "You have created a new stack {stack} on board {board}" : "لقد قمت بانشاء حزمة جديدة {stack} على اللوح {board}",
-    "{user} has created a new stack {stack} on board {board}" : "{user} قام بانشاء حزمة جديدة {stack} على اللوح {board}",
-    "You have renamed stack {before} to {stack} on board {board}" : "قمت باعادة تسمية الحزمة من {before} الى {stack} على اللوح {board}",
-    "{user} has renamed stack {before} to {stack} on board {board}" : "{user} قام باعادة تسمية الحزمة {before} الى {stack} على اللوح {board}",
-    "You have deleted stack {stack} on board {board}" : "قمت بمسح الحزمة  {stack} على اللوح {board}",
-    "{user} has deleted stack {stack} on board {board}" : "{user} قام بمسح الحزمة {stack} على اللوح {board}",
-    "You have created card {card} in stack {stack} on board {board}" : "لقد قمت بانشاء بطاقة {card} في الحزمة {stack} على اللوح {board}",
-    "{user} has created card {card} in stack {stack} on board {board}" : "{user} قام بانشاء بطاقة {card} في الحزمة {stack} على اللوح {board}",
-    "You have deleted card {card} in stack {stack} on board {board}" : "قمت بمسح بطاقة {card} في الحزمة {stack} على اللوح {board}",
     "Personal" : "شخصي",
     "No data was provided to create an attachment." : "لا بيانات تم تقديمها لانشاء مرفق",
     "Finished" : "إكتمل",
@@ -96,7 +87,6 @@ OC.L10N.register(
     "Can share" : "يمكن مشاركته",
     "Can manage" : "يمكن ادارته",
     "Delete" : "حذف ",
-    "Add a new stack" : "إضافة حزمة جديدة",
     "Delete list" : "حذف القائمة",
     "Add card" : "إضافة بطاقة",
     "Add a new card" : "إضافة بطاقة جديدة",
@@ -118,9 +108,9 @@ OC.L10N.register(
     "Description" : "الوصف",
     "(Unsaved)" : "(غير محفوظ)",
     "(Saving…)" : "(يُحفظ..)",
-    "Add Attachment" : "أضف ملحق",
     "Edit description" : "تعديل الوصف",
     "View description" : "إظهار الوصف",
+    "Add Attachment" : "أضف ملحق",
     "Attachments" : "المرفقات",
     "Comments" : "تعليقات",
     "Choose attachment" : "اختيار مرفق",
@@ -142,12 +132,10 @@ OC.L10N.register(
     "Move card" : "حرك البطاقة",
     "Card details" : "تفاصيل البطاقة",
     "Move card to another board" : "حرك البطاقة الى لوح اخر",
-    "Select a stack" : "حدد حزمة",
     "All boards" : "جميع الالواح",
     "Archived boards" : "الالواح المؤرشفة",
     "Shared with you" : "شورك معك",
     "Limit deck usage of groups" : "استخدام دك   Deck محدود للمجاميع",
-    "Settings" : "الإعدادات",
     "New board title" : "عنوان لوح جديد",
     "Edit board" : "تعديل اللوح",
     "Board details" : "تفاصيل لوح",
