@@ -22,7 +22,6 @@ OC.L10N.register(
     "Update" : "পরিবর্ধন",
     "(group)" : "(গোষ্ঠি)",
     "seconds ago" : "সেকেন্ড পূর্বে",
-    "Shared with you" : "Shared with you",
-    "Settings" : "সেটিংস"
+    "Shared with you" : "Shared with you"
 },
 "nplurals=2; plural=(n != 1);");
