@@ -17,42 +17,42 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "{user} zaarchivoval(a) tabuli {before}",
     "You have unarchived the board {board}" : "Vrátili jste zpět z archivace tabuli {board}",
     "{user} has unarchived the board {before}" : "{user} vrátil(a) tabuli {before} zpět z archivace",
-    "You have created a new stack {stack} on board {board}" : "Vytvořili jste nový sloupec {stack} na tabuli {board}",
-    "{user} has created a new stack {stack} on board {board}" : "{user} vytvořil(a) nový sloupec {stack} na tabuli {board}",
-    "You have renamed stack {before} to {stack} on board {board}" : "Přejmenovali jste sloupec {before} na {stack} na tabuli {board}",
-    "{user} has renamed stack {before} to {stack} on board {board}" : "{user} přejmenoval(a) sloupec {before} na {stack} na tabuli {board}",
-    "You have deleted stack {stack} on board {board}" : "Smazali jste sloupec {stack} na tabuli {board}",
-    "{user} has deleted stack {stack} on board {board}" : "{user} smazal(a) sloupec {stack} na tabuli {board}",
-    "You have created card {card} in stack {stack} on board {board}" : "Vytvořili jste kartu {card} ve sloupci {stack} na tabuli {board}",
-    "{user} has created card {card} in stack {stack} on board {board}" : "{user} vytvořil(a) kartu {card} ve sloupci {stack} na tabuli {board}",
-    "You have deleted card {card} in stack {stack} on board {board}" : "Smazali jste kartu {card} ve sloupci {stack} na tabuli {board}",
-    "{user} has deleted card {card} in stack {stack} on board {board}" : "{user} smazal(a) kartu {card} ve sloupci {board} na tabuli {board}",
+    "You have created a new list {stack} on board {board}" : "Vytvořili jste nový sloupec {stack} na tabuli {board}",
+    "{user} has created a new list {stack} on board {board}" : "{user} vytvořil(a) nový sloupec {stack} na tabuli {board}",
+    "You have renamed list {before} to {stack} on board {board}" : "Přejmenovali jste sloupec {before} na {stack} na tabuli {board}",
+    "{user} has renamed list {before} to {stack} on board {board}" : "{user} přejmenoval(a) sloupec {before} na {stack} na tabuli {board}",
+    "You have deleted list {stack} on board {board}" : "Smazali jste sloupec {stack} na tabuli {board}",
+    "{user} has deleted list {stack} on board {board}" : "{user} smazal(a) sloupec {stack} na tabuli {board}",
+    "You have created card {card} in list {stack} on board {board}" : "Vytvořili jste kartu {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has created card {card} in list {stack} on board {board}" : "{user} vytvořil(a) kartu {card} ve sloupci {stack} na tabuli {board}",
+    "You have deleted card {card} in list {stack} on board {board}" : "Smazali jste kartu {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} smazal(a) kartu {card} ve sloupci {board} na tabuli {board}",
     "You have renamed the card {before} to {card}" : "Přejmenovali jste kartu {before} na {card}",
     "{user} has renamed the card {before} to {card}" : "{user} přejmenoval(a) {before} na {card}",
-    "You have added a description to card {card} in stack {stack} on board {board}" : "Přidali jste popis ke kartě {card} ve sloupci {stack} na tabuli {board}",
-    "{user} has added a description to card {card} in stack {stack} on board {board}" : "{user} přidal(a) popis ke kartě {card} ve sloupci {stack} na tabuli {board}",
-    "You have updated the description of card {card} in stack {stack} on board {board}" : "Aktualizovali jste popis karty {card} ve sloupci {stack} na tabuli {board}",
-    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "{user} aktualizoval(a) popis karty {card} ve sloupci {stack} na tabuli {board}",
-    "You have archived card {card} in stack {stack} on board {board}" : "Zaarchivovali kartu {card} ve sloupci {stack} na tabuli {board}",
-    "{user} has archived card {card} in stack {stack} on board {board}" : "{user} zaarchivoval(a) kartu {card} ve sloupci {stack} na tabuli {board}",
-    "You have unarchived card {card} in stack {stack} on board {board}" : "Zrušili jste archivaci karty {card} ve sloupci {stack} na tabuli {board}",
-    "{user} has unarchived card {card} in stack {stack} on board {board}" : "{user} zrušil(a) archivaci karty {card} ve sloupci {stack} na tabuli {board}",
+    "You have added a description to card {card} in list {stack} on board {board}" : "Přidali jste popis ke kartě {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} přidal(a) popis ke kartě {card} ve sloupci {stack} na tabuli {board}",
+    "You have updated the description of card {card} in list {stack} on board {board}" : "Aktualizovali jste popis karty {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} aktualizoval(a) popis karty {card} ve sloupci {stack} na tabuli {board}",
+    "You have archived card {card} in list {stack} on board {board}" : "Zaarchivovali kartu {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has archived card {card} in list {stack} on board {board}" : "{user} zaarchivoval(a) kartu {card} ve sloupci {stack} na tabuli {board}",
+    "You have unarchived card {card} in list {stack} on board {board}" : "Zrušili jste archivacii karty {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} zrušil(a) archivaci karty {card} ve sloupci {stack} na tabuli {board}",
     "You have removed the due date of card {card}" : "Odebrali jste termín u karty {card}",
     "{user} has removed the due date of card {card}" : "{user} odebral(a) termín u karty {card}",
     "You have set the due date of card {card} to {after}" : "Nastavili jste termín u karty {card} na {after}",
     "{user} has set the due date of card {card} to {after}" : "{user} nastavil(a) termín u karty {card} na {after}",
     "You have updated the due date of card {card} to {after}" : "Změnili jste termín u karty {card} na {after}",
     "{user} has updated the due date of card {card} to {after}" : "{user} aktualizoval(a) termín u karty {card} na {after}",
-    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "Přidali jste štítek {label} kartě {card} ve sloupci {stack} na tabuli {board}",
-    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "{user} přidal(a) štítek {label} ke kartě {card} ve sloupci {stack} na tabuli {board}",
-    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "Odebrali jste štítek {label} z karty {card} ve sloupci {stack} na tabuli {board}",
-    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "{user} odebral(a) štítek {label} z karty {card} ve sloupci {stack} na tabuli {board}",
+    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Přidali jste štítek {label} kartě {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} přidal(a) štítek {label} ke kartě {card} ve sloupci {stack} na tabuli {board}",
+    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Odebrali jste štítek {label} z karty {card} ve sloupci {stack} na tabuli {board}",
+    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} odebral(a) štítek {label} z karty {card} ve sloupci {stack} na tabuli {board}",
     "You have assigned {assigneduser} to card {card} on board {board}" : "Přiřadili jste {assigneduser} ke kartě {card} na tabuli {board}",
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} přiřadil(a) {assigneduser} ke kartě {card} na tabuli {board}",
     "You have unassigned {assigneduser} from card {card} on board {board}" : "Zrušili jste přiřazení {assigneduser} u karty {card} na tabuli {board}",
     "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} zrušil(a) přiřazení {assigneduser} z karty {card} na tabuli {board}",
-    "You have moved the card {card} from stack {stackBefore} to {stack}" : "Přesunuli jste kartu {card} ze sloupce {stackBefore} do {stack}",
-    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "{user} přesunul(a) kartu {card} ze sloupce {stackBefore} do {stack}",
+    "You have moved the card {card} from list {stackBefore} to {stack}" : "Přesunuli jste kartu {card} ze sloupce {stackBefore} do {stack}",
+    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} přesunul(a) kartu {card} ze sloupce {stackBefore} do {stack}",
     "You have added the attachment {attachment} to card {card}" : "Přidali jste přílohu {attachment} ke kartě {card}",
     "{user} has added the attachment {attachment} to card {card}" : "{user} přidal(a) přílohu {attachment} ke kartě {card}",
     "You have updated the attachment {attachment} on card {card}" : "Aktualizovali jste přílohu {attachment} u karty {card}",
@@ -148,7 +148,7 @@ OC.L10N.register(
     "Can share" : "Může sdílet",
     "Can manage" : "Může spravovat",
     "Delete" : "Smazat",
-    "Add a new stack" : "Přidat nový sloupec",
+    "Add a new list" : "Přidat nový sloupec",
     "Delete list" : "Smazat seznam",
     "Add card" : "Přidat kartu",
     "Add a new card" : "Přidat novou kartu",
@@ -171,9 +171,9 @@ OC.L10N.register(
     "(Unsaved)" : "(Neuloženo)",
     "(Saving…)" : "(Ukládání…)",
     "Formatting help" : "Nápověda k formátování",
-    "Add Attachment" : "Přidat přílohu",
     "Edit description" : "Upravit popis",
     "View description" : "Zobrazit popis",
+    "Add Attachment" : "Přidat přílohu",
     "Attachments" : "Přílohy",
     "Comments" : "Komentáře",
     "Choose attachment" : "Zvolte přílohu",
@@ -191,19 +191,19 @@ OC.L10N.register(
     "(circle)" : "(okruh)",
     "seconds ago" : "před několika sekundami",
     "Assign to me" : "Přiřadit mě",
+    "Unassign myself" : "Zrušit přiřazení sobě",
     "Unarchive card" : "Zrušit archivaci karty",
     "Archive card" : "Archivovat kartu",
     "Delete card" : "Smazat kartu",
     "Move card" : "Přesunout kartu",
     "Card details" : "Podrobnosti o kartě",
     "Move card to another board" : "Přesunout kartu na jinou tabuli",
-    "Select a stack" : "Vybrat sloupec",
+    "Select a list" : "Vyberte sloupec",
     "All boards" : "Všechny tabule",
     "Archived boards" : "Archivované tabule",
     "Shared with you" : "Sdíleno s vámi",
     "Limit deck usage of groups" : "Omezit využití deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení nastavené pro Deck brání uživatelům, kteří nejsou součástí těchto skupin, ve vytváření vlastních tabulí. Nicméně i tak ale pořád budou moci pracovat na tabulích, které jsou jim nasdíleny.",
-    "Settings" : "Nastavení",
     "New board title" : "Název nové tabule",
     "Edit board" : "Upravit tabuli",
     "Clone board " : "Klonovat tabuli ",
