@@ -29,7 +29,6 @@ OC.L10N.register(
     "Can edit" : "Can edit",
     "Can share" : "Kan dele",
     "Delete" : "Slet",
-    "Add a new stack" : "Tilføj en ny stak",
     "Delete list" : "Slet liste",
     "Add card" : "Tilføj kort",
     "Edit" : "Redigér",
@@ -54,7 +53,6 @@ OC.L10N.register(
     "Move card" : "Flyt kort",
     "Archived boards" : "Arkiverede lister",
     "Shared with you" : "Shared with you",
-    "Settings" : "Indstillinger",
     "New board title" : "Ny titel på liste",
     "Edit board" : "Rediger liste",
     "Board details" : "Liste detaljer",
