@@ -32,7 +32,6 @@ OC.L10N.register(
     "Can edit" : "Can edit",
     "Can share" : "Can share",
     "Delete" : "Delete",
-    "Add a new stack" : "Add a new stack",
     "Add card" : "Add card",
     "Edit" : "Edit",
     "Title" : "Title",
@@ -55,7 +54,6 @@ OC.L10N.register(
     "Delete card" : "Delete card",
     "Archived boards" : "Archived boards",
     "Shared with you" : "Shared with you",
-    "Settings" : "Settings",
     "New board title" : "New board title",
     "Edit board" : "Edit board",
     "Board details" : "Board details"
