@@ -28,7 +28,6 @@ OC.L10N.register(
     "Can edit" : "Puede editar",
     "Can share" : "Puede compartir",
     "Delete" : "Borrar",
-    "Add a new stack" : "Agregar una nueva pila",
     "Add card" : "Agregar tarjeta",
     "Edit" : "Editar",
     "Title" : "Título",
@@ -48,7 +47,6 @@ OC.L10N.register(
     "seconds ago" : "hace segundos",
     "Archived boards" : "Tableros archivados",
     "Shared with you" : "Compartido con usted",
-    "Settings" : "Configuraciones ",
     "New board title" : "Nuevo título del tablero",
     "Edit board" : "Editar el tablero",
     "Board details" : "Detalles del tablero"
