@@ -17,9 +17,6 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "הארכיון {before} הועבר לארכיון על ידי {user}",
     "You have unarchived the board {board}" : "הוצאת את הלוח {board} מהארכיון",
     "{user} has unarchived the board {before}" : "הלוח {before} הוצא מהארכיון על ידי {user}",
-    "You have created a new stack {stack} on board {board}" : "יצרת ערימה חדשה {stack} בלוח {board}",
-    "{user} has created a new stack {stack} on board {board}" : "נוצרה ערימה חדשה {stack} בלוח {board} על ידי {user}",
-    "You have renamed stack {before} to {stack} on board {board}" : "שינית את שם הערימה {before} לשם {stack} בלוח {board}",
     "You have removed the due date of card {card}" : "הסרת את מועד היעד מהכרטיס {card}",
     "{user} has removed the due date of card {card}" : "מועד היעד של הכרטיס {card} הוסר על ידי {user}",
     "You have commented on card {card}" : "הגבת על הכרטיס {cart}",
@@ -108,7 +105,6 @@ OC.L10N.register(
     "Can share" : "Can share",
     "Can manage" : "הרשאת ניהול",
     "Delete" : "מחיקה",
-    "Add a new stack" : "הוספת ערימה חדשה",
     "Delete list" : "מחיקת רשימה",
     "Add card" : "הוספת כרטיס",
     "Add a new card" : "הוספת כרטיס חדש",
@@ -131,9 +127,9 @@ OC.L10N.register(
     "(Unsaved)" : "(לא נשמר)",
     "(Saving…)" : "(מתבצעת שמירה…)",
     "Formatting help" : "עזרה בסידור בתבנית",
-    "Add Attachment" : "הוספת קובץ מצורף",
     "Edit description" : "עריכת תיאור",
     "View description" : "הצגת תיאור",
+    "Add Attachment" : "הוספת קובץ מצורף",
     "Attachments" : "קבצים מצורפים",
     "Comments" : "תגובות",
     "Choose attachment" : "בחירת קובץ מצורף",
@@ -157,13 +153,11 @@ OC.L10N.register(
     "Move card" : "העברת כרטיס",
     "Card details" : "פרטי הכרטיס",
     "Move card to another board" : "העברת כרטיס ללוח אחר",
-    "Select a stack" : "בחירת ערימה",
     "All boards" : "כל הלוחות",
     "Archived boards" : "לוחות שנשמרו בארכיון",
     "Shared with you" : "משותף אתך",
     "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם.",
-    "Settings" : "הגדרות",
     "New board title" : "כותרת לוח חדשה",
     "Edit board" : "עריכת לוח",
     "Clone board " : "שכפול לוח",
