@@ -16,7 +16,6 @@ OC.L10N.register(
     "Save" : "Պահպանել",
     "Update" : "Թարմացնել",
     "seconds ago" : "վրկ. առաջ",
-    "Shared with you" : "Shared with you",
-    "Settings" : "կարգավորումներ"
+    "Shared with you" : "Shared with you"
 },
 "nplurals=2; plural=(n != 1);");
