@@ -17,42 +17,42 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "{user} は {before} のボードをアーカイブしました",
     "You have unarchived the board {board}" : "ボード {board} がアーカイブされていません",
     "{user} has unarchived the board {before}" : "{user} は {before} のボードをアーカイブされていません",
-    "You have created a new stack {stack} on board {board}" : "{board} に新しいスタック {stack} を作成しました。",
-    "{user} has created a new stack {stack} on board {board}" : "{user} が {board} に新しいスタック {stack} を作成しました",
-    "You have renamed stack {before} to {stack} on board {board}" : " {board} のスタックの名前を {before} から {stack} に変更しました",
-    "{user} has renamed stack {before} to {stack} on board {board}" : "{user} がボード {board} のスタックの名前を {before} から {stack} に変更しました",
-    "You have deleted stack {stack} on board {board}" : "ボード {board} のスタック {stack} を削除しました。",
-    "{user} has deleted stack {stack} on board {board}" : "{user} がボード {board} のスタック {stack} を削除しました。",
-    "You have created card {card} in stack {stack} on board {board}" : "{board} の {stack} に {card} を作成しました。",
-    "{user} has created card {card} in stack {stack} on board {board}" : "{user} が {board} の {stack} に {card} を作成しました",
-    "You have deleted card {card} in stack {stack} on board {board}" : "{board} の {stack} で {card} を削除しました。",
-    "{user} has deleted card {card} in stack {stack} on board {board}" : "{user}がボード{board}のスタック{stack}のカード{card}を削除しました",
+    "You have created a new list {stack} on board {board}" : "ボード{board} に新しいリスト {stack} を作成しました。",
+    "{user} has created a new list {stack} on board {board}" : "{user} がボード {board} に新しいリスト {stack} を作成しました",
+    "You have renamed list {before} to {stack} on board {board}" : "ボード {board} のリストの名を {before} から {stack} に変更しました",
+    "{user} has renamed list {before} to {stack} on board {board}" : "{user} がボード {board} のリスト名を {before} から {stack} に変更しました",
+    "You have deleted list {stack} on board {board}" : "ボード {board} のリスト {stack} を削除しました。",
+    "{user} has deleted list {stack} on board {board}" : "{user} がボード {board} のリスト {stack} を削除しました。",
+    "You have created card {card} in list {stack} on board {board}" : "ボード{board} のリスト {stack} に カード{card} を作成しました。",
+    "{user} has created card {card} in list {stack} on board {board}" : "{user} がボード {board} のリスト {stack} にカード {card} を作成しました",
+    "You have deleted card {card} in list {stack} on board {board}" : "ボード{board} のリスト {stack} のカード {card} を削除しました。",
+    "{user} has deleted card {card} in list {stack} on board {board}" : "{user}がボード{board}のリスト{stack}のカード{card}を削除しました",
     "You have renamed the card {before} to {card}" : "カード {before} の名前を {card} に変更しました",
     "{user} has renamed the card {before} to {card}" : "{user} が {before} カードの名前を {card} に変更しました",
-    "You have added a description to card {card} in stack {stack} on board {board}" : "ボード{board}のスタック{stack} のカード{card}に説明を追加しました",
-    "{user} has added a description to card {card} in stack {stack} on board {board}" : "{user}がボード{board}のスタック{stack}のカード{card}に説明を追加しました",
-    "You have updated the description of card {card} in stack {stack} on board {board}" : "ボード{board}のスタック{stack}のカード{card}の説明を更新しました",
-    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "{user}はボード{board}のスタック{stack}のカード{card}の説明を更新しました",
-    "You have archived card {card} in stack {stack} on board {board}" : "ボード {board}上のスタック {stack}にあるカード {card} をアーカイブしました",
-    "{user} has archived card {card} in stack {stack} on board {board}" : "{user}がボード{board}のスタック{stack}にカード{card}をアーカイブしました",
-    "You have unarchived card {card} in stack {stack} on board {board}" : "ボード{board}のスタック{stack}に未アーカイブのカード{card}があります",
-    "{user} has unarchived card {card} in stack {stack} on board {board}" : "{user}がボード {board}上のスタック {stack}にあるカード {card} をアーカイブ解除しました",
+    "You have added a description to card {card} in list {stack} on board {board}" : "ボード{board}のリスト{stack} のカード{card}に説明を追加しました",
+    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user}がボード{board}のリスト{stack}のカード{card}に説明を追加しました",
+    "You have updated the description of card {card} in list {stack} on board {board}" : "ボード{board}のリスト{stack}のカード{card}の説明を更新しました",
+    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user}はボード{board}のリスト{stack}のカード{card}の説明を更新しました",
+    "You have archived card {card} in list {stack} on board {board}" : "ボード {board}のリスト {stack}にあるカード {card} をアーカイブしました",
+    "{user} has archived card {card} in list {stack} on board {board}" : "{user}がボード{board}のリスト{stack}にカード{card}をアーカイブしました",
+    "You have unarchived card {card} in list {stack} on board {board}" : "ボード {board}のリスト {stack}にあるカード {card} をアーカイブ解除しました",
+    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user}がボード {board}のリスト {stack}にあるカード {card} をアーカイブ解除しました",
     "You have removed the due date of card {card}" : "カード{card}の期日を削除しました",
     "{user} has removed the due date of card {card}" : "{user}がカード{card}の期日を削除しました",
     "You have set the due date of card {card} to {after}" : "カード{card}の期日を{after}に設定しました",
     "{user} has set the due date of card {card} to {after}" : "{user}がカード{card}の期日を{after}に設定しました",
     "You have updated the due date of card {card} to {after}" : "カード{card}の期日を{after}に更新しました",
     "{user} has updated the due date of card {card} to {after}" : "{user}はカード{card}の期日を{after}に更新しました",
-    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "ボード{board}のスタック{stack}のカード{card}にタグ{label}を追加しました",
-    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "{user}がボード{board}のスタック{stack}のカード{card}にタグ{label}を追加しました",
-    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "ボード{board}のスタック{stack}のカード{card}からタグ{label}を削除しました",
-    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "{user}がボード{board}のスタック{stack}のカード{card}からタグ{label}を削除しました",
+    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "ボード{board}のリスト{stack}のカード{card}にタグ{label}を追加しました",
+    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user}がボード{board}のリスト{stack}のカード{card}にタグ{label}を追加しました",
+    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "ボード{board}のリスト{stack}のカード{card}からタグ{label}を削除しました",
+    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user}がボード{board}のリスト{stack}のカード{card}からタグ{label}を削除しました",
     "You have assigned {assigneduser} to card {card} on board {board}" : "ボード{board}のカード{card}に{assigneduser}を割り当てました",
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user}がボード{board}のカード{card}に{assigneduser}を割り当てました",
     "You have unassigned {assigneduser} from card {card} on board {board}" : "ボード{board}のカード{card}から{assigneduser} の割り当てが解除されました",
     "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user}がボード{board}のカード{card}から{assigneduser}の割り当てを解除されました",
-    "You have moved the card {card} from stack {stackBefore} to {stack}" : "カード{card}をスタック{stackBefore}から{stack}に移動しました",
-    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "{user}がカード{card}をスタック{stackBefore}から{stack}に移動しました",
+    "You have moved the card {card} from list {stackBefore} to {stack}" : "カード{card}をリスト{stackBefore}から{stack}に移動しました",
+    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user}がカード{card}をリスト{stackBefore}から{stack}に移動しました",
     "You have added the attachment {attachment} to card {card}" : "添付ファイル{attachment}をカード{card}に追加しました",
     "{user} has added the attachment {attachment} to card {card}" : "{user}が添付ファイル{attachment}をカード{card}に追加しました",
     "You have updated the attachment {attachment} on card {card}" : "カード{card}の添付ファイル{attachment}を更新しました",
@@ -96,67 +96,128 @@ OC.L10N.register(
     "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
     "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
     "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
+    "Personal planning and team project organization" : "個人的な計画とチームのプロジェクト編成",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合した、チームの個人計画とプロジェクトの組織化を目的としたカンバンスタイルの組織ツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 マークダウンで追加のメモを書き留めます\n- 🔖 より良い組織のためにラベルを割り当てる\n- 👥 あなたのチーム、友人、家族と共有する\n- 📎 ファイルを添付してマークダウンの説明に埋め込む\n- 💬 コメントを使ってあなたのチームと話し合う\n- ⚡ アクティビティの流れの変化を追跡する\n- 🚀 プロジェクトを整理する",
     "Create new board" : "新しいボードを作成",
+    "new board" : "新しいボード",
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
+    "Search by board title" : "ボードのタイトルで検索",
     "Select board" : "ボードを選択",
+    "Select the card to link to a project" : "プロジェクトにリンクするカードを選択",
+    "Select a board" : "ボードを選択",
+    "Select a card" : "カードを選択",
+    "Link to card" : "カードへリンク",
     "Cancel" : "キャンセル",
     "File already exists" : "ファイルはすでに存在します",
+    "A file with the name {filename} already exists." : "そのファイル名 {filename}はすでに存在します。",
     "Do you want to overwrite it?" : "上書きしますか？",
+    "Overwrite file" : "ファイルを上書き",
+    "Keep existing file" : "既存のファイルを残す",
+    "This board is read only" : "このボードは読み込みのみです",
+    "Drop your files to upload" : "アップロードするファイルをドロップしてください",
     "Archived cards" : "カードをアーカイブ",
+    "Add new list" : "新しいリストを追加",
+    "List name" : "リスト名",
+    "Apply filter" : "フィルターを適用",
     "Filter by tag" : "タグによるフィルター",
     "Filter by assigned user" : "割当ユーザーでフィルター",
     "Filter by due date" : "期限でフィルター",
     "Overdue" : "期限超過",
+    "Next 24 hours" : "次の24時間",
     "Next 7 days" : "次の7日間",
     "Next 30 days" : "次の30日間",
     "No due date" : "期限なし",
+    "Clear filter" : "フィルターをクリア",
     "Show archived cards" : "アーカイブされたカードを表示する",
     "Toggle compact mode" : "コンパクトモードの切り替え",
     "Details" : "詳細",
+    "Loading board" : "ボードを読み込み中",
+    "Board not found" : "ボードが見つかりません",
     "Sharing" : "共有中",
     "Tags" : "タグ",
     "Deleted items" : "削除されたアイテム",
     "Timeline" : "タイムライン",
+    "Deleted lists" : "削除済みリスト",
     "Undo" : "元に戻す",
     "Deleted cards" : "削除済みのカード",
+    "Share board with a user, group or circle …" : "ボードをユーザー、グループまたはサークルと共有…",
+    "Board owner" : "ボード所有者",
     "(Group)" : "(グループ)",
+    "(Circle)" : "(サークル)",
     "Can edit" : "編集可能",
     "Can share" : "共有可能",
+    "Can manage" : "管理可能",
     "Delete" : "削除",
-    "Add a new stack" : "新しいスタックを追加する",
+    "Add a new list" : "新しいリストを追加",
     "Delete list" : "リストを削除",
     "Add card" : "カードを追加",
+    "Add a new card" : "新しいカードを追加",
     "Edit" : "編集",
+    "Add a new tag" : "新しいタグを追加",
+    "title and color value must be provided" : "タイトルと色の値を指定する必要があります",
     "Title" : "タイトル",
     "Members" : "メンバー",
+    "Add this attachment" : "この添付ファイルを追加",
+    "Delete Attachment" : "添付ファイルを削除",
+    "Restore Attachment" : "添付ファイルを復元",
+    "Assign a tag to this card…" : "タグこのをカードに割り当てる…",
+    "Assign to users" : "ユーザーに割り当てる",
+    "Assign to users/groups/circles" : "ユーザー/グループ/サークルに割り当てる",
+    "Assign a user to this card…" : "このカードにユーザーに割り当てる…",
     "Due date" : "期限",
+    "Set a due date" : "期限を設定",
     "Remove due date" : "期限を削除",
     "Description" : "説明",
+    "(Unsaved)" : "(未保存)",
+    "(Saving…)" : "(保存中…)",
     "Formatting help" : "ヘルプの書式設定",
+    "Edit description" : "説明を編集",
+    "View description" : "説明を表示",
+    "Add Attachment" : "添付ファイルを追加",
     "Attachments" : "添付ファイル",
     "Comments" : "コメント",
+    "Choose attachment" : "添付ファイルを選択",
     "Modified" : "更新日時",
     "Created" : "作成時刻",
     "Upload attachment" : "添付ファイルをアップロードする",
+    "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
     "Save" : "保存",
+    "The comment cannot be empty." : "コメントを空にすることはできません。",
+    "The comment cannot be longer than 1000 characters." : "コメントは1000文字を超えることはできません。",
+    "In reply to" : "返信",
     "Reply" : "返信",
     "Update" : "更新",
     "(group)" : "(グループ)",
+    "(circle)" : "(サークル)",
     "seconds ago" : "数秒前",
+    "Assign to me" : "自分に割り当てる",
+    "Unassign myself" : "自分への割り当てを解除",
     "Unarchive card" : "カードのアーカイブを解除する",
     "Archive card" : "カードをアーカイブ",
     "Delete card" : "カードを削除する",
     "Move card" : "カードの移動",
+    "Card details" : "カード詳細",
+    "Move card to another board" : "カードを他のボードに移動",
+    "Select a list" : "リストを選択",
+    "All boards" : "すべてのボード",
     "Archived boards" : "アーカイブ済みのボード",
     "Shared with you" : "あなたと共有済み",
+    "Limit deck usage of groups" : "デッキの使用をグループに制限",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。",
-    "Settings" : "設定",
     "New board title" : "新しいボードのタイトル",
     "Edit board" : "ボードを編集",
+    "Clone board " : "ボードを複製",
+    "Unarchive board " : "ボードのアーカイブを解除",
+    "Archive board " : "ボードをアーカイブ",
+    "Delete board " : "ボードを削除",
     "Board details" : "ボードの詳細",
+    "Board {0} deleted" : "ボード {0} 削除済み",
     "An error occurred" : "エラーが発生しました",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "このボード{title}を削除してもよろしいですか？この操作はこのボードのデータすべてを削除します。",
+    "Delete the board?" : "ボードを削除しますか？",
     "Link to a board" : "ボードへのリンク",
+    "Link to a card" : "カードへリンク",
+    "Something went wrong" : "何かがおかしいです",
     "Maximum file size of {size} exceeded" : "最大ファイルサイズ（{size}）を超えています"
 },
 "nplurals=1; plural=0;");
