@@ -18,7 +18,6 @@ OC.L10N.register(
     "Reply" : "ឆ្លើយតប",
     "Update" : "ធ្វើ​បច្ចុប្បន្នភាព",
     "seconds ago" : "វិនាទី​មុន",
-    "Shared with you" : "Shared with you",
-    "Settings" : "ការកំណត់"
+    "Shared with you" : "Shared with you"
 },
 "nplurals=1; plural=0;");
