@@ -37,12 +37,18 @@ OC.L10N.register(
     "Keep existing file" : "기존 파일 보존",
     "This board is read only" : "읽기 전용 보드",
     "Drop your files to upload" : "업로드를 하려면 파일을 올리시오.",
+    "Archived cards" : "보관된 카드들",
     "Add new list" : "새로운 리스트 추가",
     "List name" : "리스트 추가",
     "Apply filter" : "필터링 적용",
     "Filter by tag" : "태그로 필터링",
+    "Filter by assigned user" : "지정된 사용자로 필터링",
+    "Filter by due date" : "기한으로 필터링",
     "Overdue" : "기한 넘김",
     "Next 24 hours" : "다음 24시간",
+    "Next 7 days" : "다음 7일 동안",
+    "Next 30 days" : "다음 30일 동안",
+    "No due date" : "기한 없음",
     "Show archived cards" : "보관된 카드 보기",
     "Details" : "세부사항",
     "Sharing" : "공유",
@@ -53,7 +59,6 @@ OC.L10N.register(
     "Can edit" : "편집할 수 있음",
     "Can share" : "공유할 수 있음",
     "Delete" : "삭제",
-    "Add a new stack" : "새 스택 추가",
     "Delete list" : "목록 지우기",
     "Add card" : "카드 추가",
     "Edit" : "편집",
@@ -80,7 +85,6 @@ OC.L10N.register(
     "All boards" : "모든 보드",
     "Archived boards" : "보관된 게시판",
     "Shared with you" : "나와 공유됨",
-    "Settings" : "설정",
     "New board title" : "새 게시판 제목",
     "Edit board" : "게시판 편집",
     "Board details" : "게시판 정보",
