@@ -17,40 +17,16 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "{user} užarchyvavo lentą {before}",
     "You have unarchived the board {board}" : "Jūs išarchyvavote lentą {board}",
     "{user} has unarchived the board {before}" : "{user} išarchyvavo lentą {before}",
-    "You have created a new stack {stack} on board {board}" : "Jūs lentoje {board} sukūrėte naują dėklą {stack}",
-    "{user} has created a new stack {stack} on board {board}" : "{user} lentoje {board} sukūrė naują dėklą {stack}",
-    "You have renamed stack {before} to {stack} on board {board}" : "Jūs lentoje {board} pervadinote dėklą {before} į {stack}",
-    "{user} has renamed stack {before} to {stack} on board {board}" : "{user} lentoje {board} pervadino dėklą {before} į {stack}",
-    "You have deleted stack {stack} on board {board}" : "Jūs lentoje {board} ištrynėte dėklą {stack}",
-    "{user} has deleted stack {stack} on board {board}" : "{user} lentoje {board} ištrynė dėklą {stack}",
-    "You have created card {card} in stack {stack} on board {board}" : "Jūs lentoje {board}, dėkle {stack} sukūrėte kortelę {card}",
-    "{user} has created card {card} in stack {stack} on board {board}" : "{user} lentoje {board}, dėkle {stack} sukūrė kortelę {card}",
-    "You have deleted card {card} in stack {stack} on board {board}" : "Jūs lentoje {board}, dėkle {stack} ištrynėte kortelę {card}",
-    "{user} has deleted card {card} in stack {stack} on board {board}" : "{user} lentoje {board}, dėkle {stack} ištrynė kortelę {card} ",
     "You have renamed the card {before} to {card}" : "Jūs pervadinote kortelę {before} į {card}",
     "{user} has renamed the card {before} to {card}" : "{user} pervadino kortelę {before} į {card}",
-    "You have added a description to card {card} in stack {stack} on board {board}" : "Jūs lentoje {board}, dėkle {stack} į kortelę {card} pridėjote aprašą",
-    "{user} has added a description to card {card} in stack {stack} on board {board}" : "{user} lentoje {board}, dėkle {stack} į kortelę {card} pridėjo aprašą",
-    "You have updated the description of card {card} in stack {stack} on board {board}" : "Jūs lentoje {board}, dėkle {stack} atnaujinote kortelės {card} aprašą",
-    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "{user} lentoje {board}, dėkle {stack} atnaujino kortelės {card} aprašą",
-    "You have archived card {card} in stack {stack} on board {board}" : "Jūs lentoje {board}, dėkle {stack} užarchyvavote kortelę {card}",
-    "{user} has archived card {card} in stack {stack} on board {board}" : "{user} lentoje {board}, dėkle {stack} užarchyvavo kortelę {card}",
-    "You have unarchived card {card} in stack {stack} on board {board}" : "Jūs lentoje {board}, dėkle {stack} išarchyvavote kortelę {card}",
-    "{user} has unarchived card {card} in stack {stack} on board {board}" : "{user} lentoje {board}, dėkle {stack} išarchyvavo kortelę {card}",
     "You have removed the due date of card {card}" : "Jūs pašalinote galutinį kortelės {card} terminą",
     "{user} has removed the due date of card {card}" : "{user} pašalino galutinį kortelės {card} terminą",
     "You have set the due date of card {card} to {after}" : "Jūs nustatėte galutinį kortelės {card} terminą į {after}",
     "{user} has set the due date of card {card} to {after}" : "{user} nustatė galutinį kortelės {card} terminą į {after}",
     "You have updated the due date of card {card} to {after}" : "Jūs atnaujinote galutinį kortelės {card} terminą į {after}",
     "{user} has updated the due date of card {card} to {after}" : "{user} atnaujino galutinį kortelės {card} terminą į {after}",
-    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "Jūs lentoje {board}, dėkle {stack} į kortelę {card} pridėjote žymę {label}",
-    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "{user} lentoje {board}, dėkle {stack} į kortelę {card} pridėjo žymę {label}",
-    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "Jūs lentoje {board}, dėkle {stack} iš kortelės {card} pašalinote žymę {label}",
-    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "{user} lentoje {board}, dėkle {stack} iš kortelės {card} pašalino žymę {label}",
     "You have assigned {assigneduser} to card {card} on board {board}" : "Jūs lentoje {board} prie kortelės {card} priskyrėte {assigneduser}",
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} lentoje {board} prie kortelės {card} priskyrė {assigneduser}",
-    "You have moved the card {card} from stack {stackBefore} to {stack}" : "Jūs perkėlėte kortelę {card} iš dėklo {stackBefore} į dėklą {stack}",
-    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "{user} perkėlė kortelę {card} iš dėklo {stackBefore} į dėklą {stack}",
     "You have added the attachment {attachment} to card {card}" : "Jūs pridėjote priedą {attachment} į kortelę {card}",
     "{user} has added the attachment {attachment} to card {card}" : "{user} pridėjo priedą {attachment} į kortelę {card}",
     "You have updated the attachment {attachment} on card {card}" : "Jūs atnaujinote priedą {attachment} kortelėje {card}",
@@ -144,7 +120,6 @@ OC.L10N.register(
     "Can share" : "Can share",
     "Can manage" : "Gali tvarkyti",
     "Delete" : "Ištrinti",
-    "Add a new stack" : "Pridėti naują dėklą",
     "Delete list" : "Ištrinti sąrašą",
     "Add card" : "Pridėti kortelę",
     "Add a new card" : "Pridėti naują kortelę",
@@ -167,9 +142,9 @@ OC.L10N.register(
     "(Unsaved)" : "(Neįrašyta)",
     "(Saving…)" : "(Įrašoma…)",
     "Formatting help" : "Formatavimo pagalba",
-    "Add Attachment" : "Pridėti priedą",
     "Edit description" : "Taisyti aprašą",
     "View description" : "Rodyti aprašą",
+    "Add Attachment" : "Pridėti priedą",
     "Attachments" : "Priedai",
     "Comments" : "Komentarai",
     "Choose attachment" : "Pasirinkite priedą",
@@ -192,11 +167,9 @@ OC.L10N.register(
     "Move card" : "Perkelti kortelę",
     "Card details" : "Išsamiau apie kortelę",
     "Move card to another board" : "Perkelti kortelę į kitą lentą",
-    "Select a stack" : "Pasirinkti dėklą",
     "All boards" : "Visos lentos",
     "Archived boards" : "Archyvuotos lentos",
     "Shared with you" : "Bendrinama su jumis",
-    "Settings" : "Nustatymai",
     "New board title" : "Naujos lentos pavadinimas",
     "Edit board" : "Taisyti lentą",
     "Clone board " : "Dubliuoti lentą ",
