@@ -16,7 +16,6 @@ OC.L10N.register(
     "Modified" : "Dimodifikasi",
     "Save" : "Simpan",
     "Update" : "Kemaskini",
-    "Shared with you" : "Shared with you",
-    "Settings" : "Tetapan"
+    "Shared with you" : "Shared with you"
 },
 "nplurals=1; plural=0;");
