@@ -17,42 +17,42 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "Používateľ {user} archivoval nástenku {board}",
     "You have unarchived the board {board}" : "Zrušili ste archiváciu nástenky {board}",
     "{user} has unarchived the board {before}" : "Používateľ {user} zrušil archiváciu nástenky {before}",
-    "You have created a new stack {stack} on board {board}" : "Vytvorili ste nový stĺpec {stack} na nástenke {board}",
-    "{user} has created a new stack {stack} on board {board}" : "Používateľ {user} vytvoril nový stĺpec {stack} na nástenke {board}",
-    "You have renamed stack {before} to {stack} on board {board}" : "Premenovali ste stĺpec {before} na {stack} na nástenke {board}",
-    "{user} has renamed stack {before} to {stack} on board {board}" : "Používateľ {user} premenoval stĺpec {before} na {stack} na nástenke {board}",
-    "You have deleted stack {stack} on board {board}" : "Vymazali ste stĺpec {stack} z nástenky {board}",
-    "{user} has deleted stack {stack} on board {board}" : "Používateľ {user} vymazal stĺpec {stack} z nástenky {board}",
-    "You have created card {card} in stack {stack} on board {board}" : "Vytvorili ste kartu {card} v stĺpci {stack} na nástenke {board}",
-    "{user} has created card {card} in stack {stack} on board {board}" : "Používateľ {user} vytvoril kartu {card} v stĺpci {stack} na nástenke {board}",
-    "You have deleted card {card} in stack {stack} on board {board}" : "Vymazali ste kartu {card} v stĺpci {stack} z nástenky {board}",
-    "{user} has deleted card {card} in stack {stack} on board {board}" : "Používateľ {user} vymazal kartu {card} v stĺpci {stack} z nástenky {board}",
+    "You have created a new list {stack} on board {board}" : "Vytvorili ste nový zoznam {stack} na nástenke {board}",
+    "{user} has created a new list {stack} on board {board}" : "{user} vytvoril nový zoznam {stack} na nástenke {board}",
+    "You have renamed list {before} to {stack} on board {board}" : "Premenovali ste zoznam {before} na {stack} na nástenke {board}",
+    "{user} has renamed list {before} to {stack} on board {board}" : "{user} premenoval zoznam {before} na {stack} na nástenke {board}",
+    "You have deleted list {stack} on board {board}" : "Odstránili ste {stack} z nástenky {board}",
+    "{user} has deleted list {stack} on board {board}" : "{user} odstránil zoznam {stack} z nástenky {board}",
+    "You have created card {card} in list {stack} on board {board}" : "Vytvorili ste kartu {card} v zozname {stack} na nástenke {board}",
+    "{user} has created card {card} in list {stack} on board {board}" : "{user} vytvoril kartu {card} v zozname {stack} na nástenke {board}",
+    "You have deleted card {card} in list {stack} on board {board}" : "Odstránili ste kartu {card} zo zoznamu {stack} na nástenke {board}",
+    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} odstránil kartu {card} zo zoznamu {stack} na nástenke {board}",
     "You have renamed the card {before} to {card}" : "Premenovali ste kartu {before} na {card}",
     "{user} has renamed the card {before} to {card}" : "Používateľ {user} premenoval kartu {before} na {card}",
-    "You have added a description to card {card} in stack {stack} on board {board}" : "Pridali ste popis ku karte {card} v stĺpci {stack} na nástenke {board}",
-    "{user} has added a description to card {card} in stack {stack} on board {board}" : "Používateľ {user} pridal popis ku karte {card} v stĺpci {stack} na nástenke {board}",
-    "You have updated the description of card {card} in stack {stack} on board {board}" : "Aktualizovali ste popis v karte {card} v stĺpci {stack} na nástenke {board}",
-    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "Používateľ {user} aktualizoval popis karty {card} v stĺpci {stack} na nástenke {board}",
-    "You have archived card {card} in stack {stack} on board {board}" : "Archivovali ste kartu {card} v stĺpci {stack} na nástenke {board}",
-    "{user} has archived card {card} in stack {stack} on board {board}" : "Používateľ {user} archivoval kartu {card} v stĺpci {stack} na nástenke {board}",
-    "You have unarchived card {card} in stack {stack} on board {board}" : "Zrušili ste archiváciu karty {card} v stĺpci {stack} na nástenke {board}",
-    "{user} has unarchived card {card} in stack {stack} on board {board}" : "Používateľ {user} zrušil archiváciu karty {card} v stĺpci {stack} na nástenke {board}",
+    "You have added a description to card {card} in list {stack} on board {board}" : "Pridali ste popis na kartu {card} v zozname {stack} na nástenke {board}",
+    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} pridal popis na kartu {card} v zozname {stack} na nástenke {board}",
+    "You have updated the description of card {card} in list {stack} on board {board}" : "Aktualizovali ste popis na karte {card} v zozname {stack} na nástenke {board}",
+    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} aktualizoval popis na karte {card} v zozname {stack} na nástenke {board}",
+    "You have archived card {card} in list {stack} on board {board}" : "Archivovali ste kartu {card} v zozname {stack} na nástenke {board}",
+    "{user} has archived card {card} in list {stack} on board {board}" : "{user} archivoval kartu {card} v zozname {stack} na nástenke {board}",
+    "You have unarchived card {card} in list {stack} on board {board}" : "Zrušili ste archiváciu karty {card} v zozname {stack} na nástenke {board}",
+    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} zrušil archiváciu karty {card} v zozname {stack} na nástenke {board}",
     "You have removed the due date of card {card}" : "Odobrali ste termín dokončenia z karty {card}",
     "{user} has removed the due date of card {card}" : "Používateľ {user} odobral termín dokončenia z karty {card}",
     "You have set the due date of card {card} to {after}" : "Nastavili ste termín dokončenia pre kartu {card} na {after}",
     "{user} has set the due date of card {card} to {after}" : "Používateľ {user} nastavil termín dokončenia karty {card} na {after}",
     "You have updated the due date of card {card} to {after}" : "Zmenili ste termín dokončenia karty {card} na {after}",
     "{user} has updated the due date of card {card} to {after}" : "Používateľ {user} aktualizoval termín dokončenia karty {card} na {after}",
-    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "Pridali ste štítok {label} ku karte {card} v stĺpci {stack} na nástenke {board}",
-    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "Používateľ {user} pridal štítok {label} ku karte {card} v stĺpci {stack} na nástenke {board}",
-    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "Odobrali ste štítok {label} z karty {card} v stĺpci {stack} na nástenke {board}",
-    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "Používateľ {user} odobral štítok {label} z karty {card} v stĺpci {stack} na nástenke {board}",
+    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Pridali ste štítok {label} ku karte {card} v zozname {stack} na nástenke {board}",
+    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} pridal štítok {label} ku karte {card} v zozname {stack} na nástenke {board}",
+    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Odstránili ste štítok {label} karty {card} v zozname {stack} na nástenke {board}",
+    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} odstránil štítok {label} karty {card} v zozname {stack} na nástenke {board}",
     "You have assigned {assigneduser} to card {card} on board {board}" : "Priradili ste používateľa {assigneduser} ku karte {card} na nástenke {board}",
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "Používateľ {user} priradil používateľa {assigneduser} ku karte {card} na nástenke {board}",
     "You have unassigned {assigneduser} from card {card} on board {board}" : "Vyradili ste priradenie používateľa {assigneduser} z karty {card} na nástenke {board}",
     "{user} has unassigned {assigneduser} from card {card} on board {board}" : "Používateľ {user} vyradil používateľa {assigneduser} z karty {card} na nástenke {board}",
-    "You have moved the card {card} from stack {stackBefore} to {stack}" : "Presunuli ste kartu {card} zo stĺpca {stackBefore} do stĺpca {stack}",
-    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "Používateľ {user} presunul kartu {card} zo stĺpca {stackBefore} do stĺpca {stack}",
+    "You have moved the card {card} from list {stackBefore} to {stack}" : "Presunuli ste kartu {card} zo zoznamu {stackBefore} na {stack}",
+    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} presunul kartu {card} zo zoznamu {stackBefore} na {stack}",
     "You have added the attachment {attachment} to card {card}" : "Pridali ste prílohu {attachment} ku karte {card}",
     "{user} has added the attachment {attachment} to card {card}" : "Používateľ {user} pridal prílohu {attachment} ku karte {card}",
     "You have updated the attachment {attachment} on card {card}" : "Aktualizovali ste prílohu {attachment} na karte {card}",
@@ -148,7 +148,7 @@ OC.L10N.register(
     "Can share" : "Môže sprístupniť",
     "Can manage" : "Môže spravovať",
     "Delete" : "Zmazať",
-    "Add a new stack" : "Pridať nový stĺpec",
+    "Add a new list" : "Pridať nový zoznam",
     "Delete list" : "Vymazať zoznam",
     "Add card" : "Pridať kartu",
     "Add a new card" : "Pridať novú kartu",
@@ -171,9 +171,9 @@ OC.L10N.register(
     "(Unsaved)" : "(Neuložené)",
     "(Saving…)" : "(Ukladanie…)",
     "Formatting help" : "Pomoc pri formátovaní",
-    "Add Attachment" : "Pridať prílohu",
     "Edit description" : "Upraviť popis",
     "View description" : "Zobraziť popis",
+    "Add Attachment" : "Pridať prílohu",
     "Attachments" : "Prílohy",
     "Comments" : "Komentáre",
     "Choose attachment" : "Vybrať prílohu",
@@ -191,19 +191,19 @@ OC.L10N.register(
     "(circle)" : "(okruh)",
     "seconds ago" : "pred niekoľkými sekundami",
     "Assign to me" : "Priradiť mne",
+    "Unassign myself" : "Zrušiť priradenie mne",
     "Unarchive card" : "Zrušiť archiváciu karty",
     "Archive card" : "Archivovať kartu",
     "Delete card" : "Zmazať kartu",
     "Move card" : "Presunúť kartu",
     "Card details" : "Podrobnosti o karte",
     "Move card to another board" : "Presunúť kartu na inú nástenku",
-    "Select a stack" : "Vybrať stĺpec",
+    "Select a list" : "Vybrať zoznam",
     "All boards" : "Všetky nástenky",
     "Archived boards" : "Archivované nástenky",
     "Shared with you" : "Vám sprístupnené",
     "Limit deck usage of groups" : "Obmedziť použitie Deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Obmedzenie Násteniek bráni používateľom, ktorí nie sú súčasťou týchto skupín, aby si vytvárali vlastné nástenky. Môžu však stále pracovať na nástenkách, ktoré im niekto sprístupní.",
-    "Settings" : "Nastavenia",
     "New board title" : "Názov novej nástenky",
     "Edit board" : "Upraviť nástenku",
     "Clone board " : "Zdvojiť nástenku",
