@@ -17,6 +17,10 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "Uporabnik {user} arhivira zbirko {board}",
     "You have unarchived the board {board}" : "Povrnete zbirko {board} iz arhiva",
     "{user} has unarchived the board {before}" : "Uporabnik {user} povrne zbirko {board} iz arhiva",
+    "You have created a new list {stack} on board {board}" : "Ustvaril si novo stolpec {stack} v zbirki {board}",
+    "{user} has created a new list {stack} on board {board}" : "Uporabnik {user} je ustvaril nov stolpec {stack} v zbirki {board}",
+    "You have renamed list {before} to {stack} on board {board}" : "Preimenoval si stolpec {before} v {stack} v zbirki {board}",
+    "{user} has renamed list {before} to {stack} on board {board}" : "Uporabnik {user} je preimenoval stolpec {before} v {stack} v zbirki {board}",
     "You have renamed the card {before} to {card}" : "Preimenujete nalogo {before} v {card}",
     "{user} has renamed the card {before} to {card}" : "{user} preimenuje nalogo {before} v {card}",
     "You have removed the due date of card {card}" : "Odstranite datum preteka z naloge {card}",
