@@ -17,18 +17,42 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "{user} har arkiverat tavlan {before}",
     "You have unarchived the board {board}" : "Du har avarkiverat tavlan {board}",
     "{user} has unarchived the board {before}" : "{user} har avarkiverat tavlan {before}",
+    "You have created a new list {stack} on board {board}" : "Du har skapat en ny lista {stack} på tavlan {board}",
+    "{user} has created a new list {stack} on board {board}" : "{user} har skapat en ny lista {stack} på tavlan {board}",
+    "You have renamed list {before} to {stack} on board {board}" : "Du har bytt namn på listan {before} till {stack} på tavlan {board}",
+    "{user} has renamed list {before} to {stack} on board {board}" : "{user} har bytt namn på listan {before} till {stack} på tavlan {board}",
+    "You have deleted list {stack} on board {board}" : "Du har raderat listan {stack} på tavlan {board}",
+    "{user} has deleted list {stack} on board {board}" : "{user} har raderat listan {stack} på tavlan {board}",
+    "You have created card {card} in list {stack} on board {board}" : "Du har skapat kortet {card} i listan {stack} på tavlan {board}",
+    "{user} has created card {card} in list {stack} on board {board}" : "{user} har skapat kortet {card} i listan {stack} på tavlan {board}",
+    "You have deleted card {card} in list {stack} on board {board}" : "Du har raderat kortet {card} i listan {stack} på tavlan {board}",
+    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} har raderat kortet {card} i listan {stack} på tavlan {board}",
     "You have renamed the card {before} to {card}" : "Du har bytt namn på kortet {before} till {card}",
     "{user} has renamed the card {before} to {card}" : "{user} har bytt namn på kortet {before} till {card}",
+    "You have added a description to card {card} in list {stack} on board {board}" : "Du har lagt till en beskrivning till kortet {card} i listan {stack} på tavlan {board}",
+    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} har lagt till en beskrivning till kortet {card} i listan {stack} på tavlan {board}",
+    "You have updated the description of card {card} in list {stack} on board {board}" : "Du har uppdaterat beskrivningen för kortet {card} i listan {stack} på tavlan {board}",
+    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} har uppdaterat beskrivningen för kortet {card} i listan {stack} på tavlan {board}",
+    "You have archived card {card} in list {stack} on board {board}" : "Du har arkiverat kortet {card} i listan {stack} på tavlan {board}",
+    "{user} has archived card {card} in list {stack} on board {board}" : "{user} har arkiverat kortet {card} i listan {stack} på tavlan {board}",
+    "You have unarchived card {card} in list {stack} on board {board}" : "Du har avarkiverat kortet {card} i listan {stack} på tavlan {board}",
+    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} har avarkiverat kortet {card} i listan {stack} på tavlan {board}",
     "You have removed the due date of card {card}" : "Du har tagit bort förfallodatum för kortet {card}",
     "{user} has removed the due date of card {card}" : "{user} tagit bort förfallodatum för kortet {card}",
     "You have set the due date of card {card} to {after}" : "Du har satt förfallodatum för kortet {card} till {after}",
     "{user} has set the due date of card {card} to {after}" : "{user} har satt förfallodatum för kortet {card} till {after}",
     "You have updated the due date of card {card} to {after}" : "Du har uppdaterat förfallodatum för kortet {card} till {after}",
     "{user} has updated the due date of card {card} to {after}" : "{user} har uppdaterat förfallodatum för kortet {card} till {after}",
+    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Du har lagt till taggen {label} till kortet {card} i listan {stack} på tavlan {board}",
+    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} har lagt till taggen {label} till kortet {card} i listan {stack} på tavlan {board}",
+    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Du har raderat taggen {label} från kortet {card} i listan {stack} på tavlan {board}",
+    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} har raderat taggen {label} från kortet {card} i listan {stack} på tavlan {board}",
     "You have assigned {assigneduser} to card {card} on board {board}" : "Du har tilldelat {assigneduser} till kortet {card} på tavlan {board}",
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} har tilldelat {assigneduser} till kortet {card} på tavlan {board}",
     "You have unassigned {assigneduser} from card {card} on board {board}" : "Du har tagit bort tilldelningen för {assigneduser} från kortet {card} på tavlan {board}",
     "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} har tagit bort tilldelningen för {assigneduser} från kortet {card} på tavlan {board}",
+    "You have moved the card {card} from list {stackBefore} to {stack}" : "Du har flyttat kortet {card} från listan {stackBefore} till {stack}",
+    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} har flyttat kortet {card} från listan {stackBefore} till {stack}",
     "You have added the attachment {attachment} to card {card}" : "Du har lagt till bilagan {attachment} till kortet {card}",
     "{user} has added the attachment {attachment} to card {card}" : "{user} har lagt till bilagan {attachment} till kortet {card}",
     "You have updated the attachment {attachment} on card {card}" : "Du har uppdaterat bilagan {attachment} på kortet {card}",
@@ -72,6 +96,7 @@ OC.L10N.register(
     "Could not write file to disk" : "Kunde inte skriva fil till disk",
     "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdningen",
     "No file uploaded or file size exceeds maximum of %s" : "Ingen fil uppladdad eller filstorleken överstiger max %s",
+    "Personal planning and team project organization" : "Personlig planering och projekthantering för teams",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Korthögar är en kanban-liknande projekt- och organiseringsapp för arbetsgrupper i Nextcloud.\n\n\n- 📥 Lägg till uppgifter på kort och ordna dem\n- 📄 Skriv anteckningar i markdown\n- 🔖 Tilldela etiketter för organisering\n- 👥 Dela med arbetsgruppen, vänner eller familj\n- 📎 Bifoga filer och bädda in dem i markdown-anteckningarna\n- 💬 Diskutera i arbetsgruppen genom kommentarer\n- ⚡ Håll koll på ändringar i aktivitetsflödet\n- 🚀 Börja organisera din arbetsgrupp nu!",
     "Create new board" : "Skapa ny tavla",
     "new board" : "ny tavla",
@@ -123,6 +148,7 @@ OC.L10N.register(
     "Can share" : "Kan dela",
     "Can manage" : "Kan hanter",
     "Delete" : "Radera",
+    "Add a new list" : "Lägg till en ny lista",
     "Delete list" : "Radera lista",
     "Add card" : "Lägg till kort",
     "Add a new card" : "Lägg till ett nytt kort",
@@ -165,12 +191,14 @@ OC.L10N.register(
     "(circle)" : "(cirkel)",
     "seconds ago" : "sekunder sedan",
     "Assign to me" : "Tilldela till mig",
+    "Unassign myself" : "Ta bort från mig själv",
     "Unarchive card" : "Avarkivera kort",
     "Archive card" : "Arkivera kort",
     "Delete card" : "Ta bort kort",
     "Move card" : "Flytta kort",
     "Card details" : "Kortdetaljer",
     "Move card to another board" : "Flytta kort till en annan tavla",
+    "Select a list" : "Välj en lista",
     "All boards" : "Alla tavlor",
     "Archived boards" : "Arkiverade tavlor",
     "Shared with you" : "Delad med dig",
