@@ -11,7 +11,6 @@ OC.L10N.register(
     "Save" : "Saqlash",
     "Update" : "Yangilash",
     "seconds ago" : "soniya oldin",
-    "Shared with you" : "Siz bilan baham ko'rdim",
-    "Settings" : "Sozlamalar"
+    "Shared with you" : "Siz bilan baham ko'rdim"
 },
 "nplurals=1; plural=0;");
