@@ -17,42 +17,18 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "{user} 已将面板 {before} 存档",
     "You have unarchived the board {board}" : "您撤销了  {board} 存档",
     "{user} has unarchived the board {before}" : "{user} 撤销了面板 {before} 存档",
-    "You have created a new stack {stack} on board {board}" : "您在面板 {board} 上创建了新任务 {stack} ",
-    "{user} has created a new stack {stack} on board {board}" : "{user} 在面板 {board} 上创建了新任务 {stack}",
-    "You have renamed stack {before} to {stack} on board {board}" : "您将面板 {board} 上的任务 {before} 重命名为 {stack}",
-    "{user} has renamed stack {before} to {stack} on board {board}" : "{user} 将面板 {board} 上的任务 {before} 重命名为 {stack}",
-    "You have deleted stack {stack} on board {board}" : "您删除了面板 {board} 上的任务 {stack}",
-    "{user} has deleted stack {stack} on board {board}" : "{user} 删除了面板 {board} 上的任务 {stack}",
-    "You have created card {card} in stack {stack} on board {board}" : "您在面板 {board} 上的任务 {stack} 中创建了卡片 {card}",
-    "{user} has created card {card} in stack {stack} on board {board}" : "{user} 在面板 {board} 上的任务 {stack} 中创建了卡片 {card}",
-    "You have deleted card {card} in stack {stack} on board {board}" : "您在面板 {board} 上的任务 {stack} 中删除了卡片 {card}",
-    "{user} has deleted card {card} in stack {stack} on board {board}" : "{user} 在面板 {board} 上的任务 {stack} 中删除了卡片 {card}",
     "You have renamed the card {before} to {card}" : "您将卡片 {before} 重命名为 {card}",
     "{user} has renamed the card {before} to {card}" : "{user} 将卡片 {before} 重命名为 {card}",
-    "You have added a description to card {card} in stack {stack} on board {board}" : "您为面板 {board} 上的任务 {stack} 中的卡片 {card} 添加了描述",
-    "{user} has added a description to card {card} in stack {stack} on board {board}" : "{user} 为面板 {board} 上的任务 {stack} 中的卡片 {card} 添加了描述",
-    "You have updated the description of card {card} in stack {stack} on board {board}" : "您更新了面板 {board} 上的任务 {stack} 中的卡片 {card} 的描述",
-    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "{user} 更新了面板 {board} 上，任务 {stack} 的卡片 {card}中的描述",
-    "You have archived card {card} in stack {stack} on board {board}" : "您已对面板 {board} 上的任务 {stack} 中的卡片 {card} 存档",
-    "{user} has archived card {card} in stack {stack} on board {board}" : "{user} 已对面板 {board} 上的任务 {stack} 中的卡片 {card} 存档",
-    "You have unarchived card {card} in stack {stack} on board {board}" : "您已对面板 {board} 上的任务 {stack} 中的卡片 {card} 恢复存档",
-    "{user} has unarchived card {card} in stack {stack} on board {board}" : "{user} 已对面板 {board} 上的任务 {stack} 中的卡片 {card} 恢复存档",
     "You have removed the due date of card {card}" : "您移除了到期的卡片 {card}",
     "{user} has removed the due date of card {card}" : "{user} 移除了到期的卡片 {card}",
     "You have set the due date of card {card} to {after}" : "您设置到期的卡片 {card} 为 {after}",
     "{user} has set the due date of card {card} to {after}" : "{user} 设置到期的卡片 {card} 为 {after}",
     "You have updated the due date of card {card} to {after}" : "您更新到期的卡片 {card} 为 {after}",
     "{user} has updated the due date of card {card} to {after}" : "{user} 更新到期的卡片 {card} 为 {after}",
-    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "您为面板 {board} 上的任务 {stack} 中的卡片 {card} 添加了标签 {label}",
-    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "{user} 为面板 {board} 上的任务 {stack} 中的卡片 {card} 添加了标签 {label}",
-    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "您移除了面板 {board} 上的任务 {stack} 中的卡片 {card} 的标签 {label}",
-    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "{user} 移除了面板 {board} 上的任务 {stack} 中的卡片 {card} 的标签 {label}",
     "You have assigned {assigneduser} to card {card} on board {board}" : "您将面板 {board} 上的卡片 {card} 指派给了 {assigneduser}",
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} 将面板 {board} 上的卡片 {card} 指派给了 {assigneduser}",
     "You have unassigned {assigneduser} from card {card} on board {board}" : "您对 {assigneduser} 取消了面板 {board} 上的卡片 {card} 指派",
     "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} 对 {assigneduser} 取消了面板 {board} 上的卡片 {card} 指派",
-    "You have moved the card {card} from stack {stackBefore} to {stack}" : "您将卡片 {card} 从任务 {stackBefore} 移到任务 {stack}",
-    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "{user} 将卡片 {card} 从任务 {stackBefore} 移到任务 {stack}",
     "You have added the attachment {attachment} to card {card}" : "您为卡片 {card}  添加了附件 {attachment}",
     "{user} has added the attachment {attachment} to card {card}" : "{user} 为卡片 {card} 添加了附件 {attachment}",
     "You have updated the attachment {attachment} on card {card}" : "您更新了卡片 {card} 中的附件 {attachment}",
@@ -101,6 +77,7 @@ OC.L10N.register(
     "Create new board" : "创建新面板",
     "new board" : "新面板",
     "Select the board to link to a project" : "选择要链接到一个项目的面板",
+    "Search by board title" : "通过标题搜索面板",
     "Select board" : "选择面板",
     "Select the card to link to a project" : "选择要链接到一个项目的卡片",
     "Select a board" : "选择一个面板",
@@ -122,9 +99,11 @@ OC.L10N.register(
     "Filter by assigned user" : "根据指定用户过滤",
     "Filter by due date" : "根据截止日期过滤",
     "Overdue" : "逾期",
+    "Next 24 hours" : "未来24小时",
     "Next 7 days" : "下个7天",
     "Next 30 days" : "下个30天",
     "No due date" : "无截止日期",
+    "Clear filter" : "清空过滤器",
     "Show archived cards" : "显示已存档的卡片",
     "Toggle compact mode" : "切换简洁模式",
     "Details" : "详情",
@@ -134,6 +113,7 @@ OC.L10N.register(
     "Tags" : "标签",
     "Deleted items" : "已删除项",
     "Timeline" : "时间线",
+    "Deleted lists" : "已删除的列表",
     "Undo" : "撤消",
     "Deleted cards" : "已删除卡片",
     "Share board with a user, group or circle …" : "与一个用户，群组或圈子共享面板...",
@@ -144,26 +124,34 @@ OC.L10N.register(
     "Can share" : "可以共享",
     "Can manage" : "可以管理",
     "Delete" : "删除",
-    "Add a new stack" : "添加一个新任务",
     "Delete list" : "删除列表",
     "Add card" : "添加卡片",
     "Add a new card" : "添加一张新卡片",
     "Edit" : "编辑",
+    "Add a new tag" : "新增一个标签",
     "title and color value must be provided" : "必须提供标题和颜色值",
     "Title" : "标题",
     "Members" : "会员",
+    "Add this attachment" : "添加此附件",
     "Delete Attachment" : "删除附件",
     "Restore Attachment" : "恢复附件",
     "Assign a tag to this card…" : "为该卡片分配标签…",
     "Assign to users" : "指派给用户",
+    "Assign to users/groups/circles" : "分配给用户/群组/圈子",
     "Assign a user to this card…" : "为该卡片指派用户…",
     "Due date" : "截至日期",
     "Set a due date" : "设置一个截止日期",
     "Remove due date" : "移除截至日期",
     "Description" : "描述",
+    "(Unsaved)" : "（未保存的）",
+    "(Saving…)" : "（正在保存...）",
     "Formatting help" : "格式化帮助",
+    "Edit description" : "编辑描述",
+    "View description" : "查看描述",
+    "Add Attachment" : "添加附件",
     "Attachments" : "附件",
     "Comments" : "评论",
+    "Choose attachment" : "选择附件",
     "Modified" : "已修改",
     "Created" : "已创建",
     "Upload attachment" : "上传附件",
@@ -175,6 +163,7 @@ OC.L10N.register(
     "Reply" : "回复",
     "Update" : "更新",
     "(group)" : "（组）",
+    "(circle)" : "（圈子）",
     "seconds ago" : "几秒前",
     "Assign to me" : "指派给我",
     "Unarchive card" : "恢复卡片存档",
@@ -182,16 +171,23 @@ OC.L10N.register(
     "Delete card" : "删除卡片",
     "Move card" : "移动卡片",
     "Card details" : "卡片详情",
-    "Select a stack" : "选择一个任务",
+    "Move card to another board" : "将卡片移到其他面板",
     "All boards" : "全部面板",
     "Archived boards" : "已归档面板",
     "Shared with you" : "收到的共享",
+    "Limit deck usage of groups" : "限制群组的看板使用",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "非面板创建用户组的用户将不能使用受限看板。但用户仍然能够使用已共享给他们的面板工作。",
-    "Settings" : "设置",
     "New board title" : "新面板标题",
     "Edit board" : "编辑面板",
+    "Clone board " : "克隆面板",
+    "Unarchive board " : "解除面板归档",
+    "Archive board " : "面板归档",
+    "Delete board " : "删除面板",
     "Board details" : "面板详情",
+    "Board {0} deleted" : "面板{0} 被删除",
     "An error occurred" : "发生错误",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "你确定你要删除 {title}面板吗？面板内所有数据都将因此被删除。",
+    "Delete the board?" : "是否删除面板？",
     "Link to a board" : "链接到一个面板",
     "Link to a card" : "链接到一张卡片",
     "Something went wrong" : "有地方出错了",
